@@ -1,18 +1,15 @@
 "quagpa" <-
 function(f,para) { 
+    if(! check.fs(f)) return()
     if(! are.pargpa.valid(para)) return()
     XI <- para$para[1] 
     A  <- para$para[2] 
     K  <- para$para[3] 
-
-    x <- vector(mode="numeric")
-    for(i in seq(1,length(f))) {
-      if(f[i] <= 0 || f[i] >= 1) {
-        if(f[i] == 0)         { x[i] <- XI; next }
-        if(f[i] == 1 & K > 0) { x[i] <- XI+A/K; next }
-        warning("argument of function is invalid")
-        return()
-      }
+    n <- length(f)
+    x <- vector(mode="numeric",length=n)
+    for(i in seq(1,n)) {
+      if(f[i] == 0)         { x[i] <- XI; next }
+      if(f[i] == 1 & K > 0) { x[i] <- XI+A/K; next }
       Y <- -log(1-f[i])
       if(K != 0) {
         Y=(1-exp(-K*Y))/K
